/*
 * pridist.d - process priority distribution.
 *             Written using DTrace (Solaris 10 3/05)
 *
 * This is a simple DTrace script that samples at 1000 Hz which process
 * is on the CPUs, and what the priority is. A distribution plot is printed.
 *
 * With priorities, the higher the priority the better chance the process
 * (actually, thread) has of being scheduled.
 *
 * This idea came from the script /usr/demo/dtrace/profpri.d, which
 * produces similar output for one particular PID.
 *
 * $Id: pridist.d 3 2007-08-01 10:50:08Z brendan $
 *
 * FIELDS:
 *              CMD             process name
 *              PID             process ID
 *              value           process priority
 *              count           number of samples of at least this priority
 *
 * BASED ON: /usr/demo/dtrace/profpri.d
 *
 * SEE ALSO:
 *           DTrace Guide "profile Provider" chapter (docs.sun.com)
 *           dispadmin(1M)
 *
 * PORTIONS: Copyright (c) 2005 Brendan Gregg.
 *
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 *
 * 13-Jun-2005	Brendan Gregg	Created this.
 * 22-Apr-2006	   "      "	Last update.
 * 14-Nov-2008	Tom Erickson	(adapted for Chime)
 */

/*
 * Copyright (c) 2008, 2010, Oracle and/or its affiliates. All rights reserved.
 */

profile:::profile-1000hz
{
	@Count[execname, pid] = lquantize(curlwpsinfo->pr_pri, 0, 170, 5);
}
